.console table,.console tr.first-row th{border:none}.console .tag_row span,.console tr.first-row .builder{position:relative;float:left;text-decoration:none;white-space:nowrap}.console .table-fixedwidth{width:initial}.console .load-indicator{width:100%;height:100%;z-index:900;background-color:#fff;display:table}.console tr.first-row,.console tr.first-row th{background-color:#fff!important}.console .load-indicator .spinner{display:table-cell;vertical-align:middle;text-align:center}.console .load-indicator .spinner p{font-weight:300;margin-top:10px}.console .column{min-width:40px;max-width:40px;width:40px}.console .tag_row td{margin:0;padding:0}.console .tag_row span{font-size:10px;overflow:hidden}.console tr.first-row .builder{font-size:12px;text-align:center;transform:rotate(-25deg);transform-origin:0 100%}.modal-big .modal-dialog{width:80%}.modal-big .fa{cursor:pointer}