window.FIXTURES = {
    "builders.fixture.json": {
        "builders": [
                {
                        "builderid": 1,
                        "description": null,
                        "masterids": [
                                1
                        ],
                        "name": "buildbot-job",
                        "tags": [
                                "job",
                                "buildbot"
                        ]
                },
                {
                        "builderid": 2,
                        "description": null,
                        "masterids": [
                                1
                        ],
                        "name": "buildbot",
                        "tags": [
                                "buildbot",
                                "trunk"
                        ]
                },
                {
                        "builderid": 3,
                        "description": null,
                        "masterids": [],
                        "name": "buildbot SQLALCHEMY:latest TESTS:pylint TWISTED:latest python:2.7",
                        "tags": [
                                "buildbot",
                                "SQLALCHEMY:latest",
                                "TESTS:pylint",
                                "TWISTED:latest",
                                "python:2.7"
                        ]
                },
                {
                        "builderid": 4,
                        "description": null,
                        "masterids": [],
                        "name": "buildbot SQLALCHEMY:latest TESTS:flake8 TWISTED:latest python:2.7",
                        "tags": [
                                "buildbot",
                                "SQLALCHEMY:latest",
                                "TWISTED:latest",
                                "python:2.7",
                                "TESTS:flake8"
                        ]
                },
                {
                        "builderid": 5,
                        "description": null,
                        "masterids": [],
                        "name": "buildbot SQLALCHEMY:latest TESTS:isort TWISTED:latest python:2.7",
                        "tags": [
                                "buildbot",
                                "SQLALCHEMY:latest",
                                "TWISTED:latest",
                                "python:2.7",
                                "TESTS:isort"
                        ]
                },
                {
                        "builderid": 6,
                        "description": null,
                        "masterids": [],
                        "name": "buildbot SQLALCHEMY:latest TESTS:docs TWISTED:latest python:2.7",
                        "tags": [
                                "buildbot",
                                "SQLALCHEMY:latest",
                                "TWISTED:latest",
                                "python:2.7",
                                "TESTS:docs"
                        ]
                },
                {
                        "builderid": 7,
                        "description": null,
                        "masterids": [],
                        "name": "buildbot SQLALCHEMY:latest TESTS:coverage TWISTED:latest python:2.7",
                        "tags": [
                                "buildbot",
                                "SQLALCHEMY:latest",
                                "TWISTED:latest",
                                "python:2.7",
                                "TESTS:coverage"
                        ]
                },
                {
                        "builderid": 8,
                        "description": null,
                        "masterids": [],
                        "name": "buildbot SQLALCHEMY:latest TESTS:js TWISTED:latest python:2.7",
                        "tags": [
                                "buildbot",
                                "SQLALCHEMY:latest",
                                "TWISTED:latest",
                                "python:2.7",
                                "TESTS:js"
                        ]
                },
                {
                        "builderid": 9,
                        "description": null,
                        "masterids": [],
                        "name": "buildbot SQLALCHEMY:latest TESTS:smokes TWISTED:latest python:2.7",
                        "tags": [
                                "buildbot",
                                "SQLALCHEMY:latest",
                                "TWISTED:latest",
                                "python:2.7",
                                "TESTS:smokes"
                        ]
                },
                {
                        "builderid": 10,
                        "description": null,
                        "masterids": [],
                        "name": "buildbot SQLALCHEMY:latest TESTS:trial TWISTED:14.0.2 python:2.7",
                        "tags": [
                                "buildbot",
                                "SQLALCHEMY:latest",
                                "python:2.7",
                                "TESTS:trial",
                                "TWISTED:14.0.2"
                        ]
                },
                {
                        "builderid": 11,
                        "description": null,
                        "masterids": [],
                        "name": "buildbot SQLALCHEMY:latest TESTS:trial TWISTED:15.4.0 python:2.7",
                        "tags": [
                                "buildbot",
                                "SQLALCHEMY:latest",
                                "python:2.7",
                                "TESTS:trial",
                                "TWISTED:15.4.0"
                        ]
                },
                {
                        "builderid": 12,
                        "description": null,
                        "masterids": [],
                        "name": "buildbot SQLALCHEMY:latest TESTS:trial TWISTED:latest python:2.7",
                        "tags": [
                                "buildbot",
                                "SQLALCHEMY:latest",
                                "TWISTED:latest",
                                "python:2.7",
                                "TESTS:trial"
                        ]
                },
                {
                        "builderid": 13,
                        "description": null,
                        "masterids": [],
                        "name": "buildbot DB_TYPE:sqlite SQLALCHEMY:latest TESTS:trial TWISTED:latest python:2.7",
                        "tags": [
                                "buildbot",
                                "SQLALCHEMY:latest",
                                "TWISTED:latest",
                                "python:2.7",
                                "TESTS:trial",
                                "DB_TYPE:sqlite"
                        ]
                },
                {
                        "builderid": 14,
                        "description": null,
                        "masterids": [],
                        "name": "buildbot DB_TYPE:mysql SQLALCHEMY:latest TESTS:trial TWISTED:latest python:2.7",
                        "tags": [
                                "buildbot",
                                "SQLALCHEMY:latest",
                                "TWISTED:latest",
                                "python:2.7",
                                "TESTS:trial",
                                "DB_TYPE:mysql"
                        ]
                },
                {
                        "builderid": 15,
                        "description": null,
                        "masterids": [],
                        "name": "buildbot SQLALCHEMY:0.8.0 TESTS:trial TWISTED:15.5.0 python:2.7",
                        "tags": [
                                "buildbot",
                                "python:2.7",
                                "TESTS:trial",
                                "SQLALCHEMY:0.8.0",
                                "TWISTED:15.5.0"
                        ]
                },
                {
                        "builderid": 16,
                        "description": null,
                        "masterids": [],
                        "name": "buildbot SQLALCHEMY:latest TESTS:trial TWISTED:15.5.0 python:2.7",
                        "tags": [
                                "buildbot",
                                "SQLALCHEMY:latest",
                                "python:2.7",
                                "TESTS:trial",
                                "TWISTED:15.5.0"
                        ]
                },
                {
                        "builderid": 17,
                        "description": null,
                        "masterids": [],
                        "name": "buildbot SQLALCHEMY:latest TESTS:trial_worker TWISTED:10.2.0 python:2.7",
                        "tags": [
                                "buildbot",
                                "SQLALCHEMY:latest",
                                "python:2.7",
                                "TESTS:trial_worker",
                                "TWISTED:10.2.0"
                        ]
                },
                {
                        "builderid": 18,
                        "description": null,
                        "masterids": [],
                        "name": "buildbot SQLALCHEMY:latest TESTS:trial_worker TWISTED:11.1.0 python:2.7",
                        "tags": [
                                "buildbot",
                                "SQLALCHEMY:latest",
                                "python:2.7",
                                "TESTS:trial_worker",
                                "TWISTED:11.1.0"
                        ]
                },
                {
                        "builderid": 19,
                        "description": null,
                        "masterids": [],
                        "name": "buildbot SQLALCHEMY:latest TESTS:trial_worker TWISTED:12.2.0 python:2.7",
                        "tags": [
                                "buildbot",
                                "SQLALCHEMY:latest",
                                "python:2.7",
                                "TESTS:trial_worker",
                                "TWISTED:12.2.0"
                        ]
                },
                {
                        "builderid": 20,
                        "description": null,
                        "masterids": [],
                        "name": "buildbot SQLALCHEMY:latest TESTS:trial_worker TWISTED:13.2.0 python:2.7",
                        "tags": [
                                "buildbot",
                                "SQLALCHEMY:latest",
                                "python:2.7",
                                "TESTS:trial_worker",
                                "TWISTED:13.2.0"
                        ]
                },
                {
                        "builderid": 21,
                        "description": null,
                        "masterids": [],
                        "name": "buildbot SQLALCHEMY:latest TESTS:trial_worker TWISTED:14.0.2 python:2.6",
                        "tags": [
                                "buildbot",
                                "SQLALCHEMY:latest",
                                "TWISTED:14.0.2",
                                "TESTS:trial_worker",
                                "python:2.6"
                        ]
                },
                {
                        "builderid": 22,
                        "description": null,
                        "masterids": [],
                        "name": "buildbot SQLALCHEMY:latest TESTS:trial_worker TWISTED:15.4.0 python:2.6",
                        "tags": [
                                "buildbot",
                                "SQLALCHEMY:latest",
                                "TWISTED:15.4.0",
                                "TESTS:trial_worker",
                                "python:2.6"
                        ]
                },
                {
                        "builderid": 23,
                        "description": null,
                        "masterids": [],
                        "name": "buildbot SQLALCHEMY:latest TESTS:coverage TWISTED:trunk python:3.5",
                        "tags": [
                                "buildbot",
                                "SQLALCHEMY:latest",
                                "TESTS:coverage",
                                "TWISTED:trunk",
                                "python:3.5"
                        ]
                },
                {
                        "builderid": 24,
                        "description": null,
                        "masterids": [],
                        "name": "buildbot SQLALCHEMY:latest TESTS:flake8 TWISTED:trunk python:3.5",
                        "tags": [
                                "buildbot",
                                "SQLALCHEMY:latest",
                                "TESTS:flake8",
                                "TWISTED:trunk",
                                "python:3.5"
                        ]
                },
                {
                        "builderid": 25,
                        "description": null,
                        "masterids": [],
                        "name": "buildbot SQLALCHEMY:latest TESTS:smokes TWISTED:latest python:3.5",
                        "tags": [
                                "buildbot",
                                "SQLALCHEMY:latest",
                                "TWISTED:latest",
                                "TESTS:smokes",
                                "python:3.5"
                        ]
                },
                {
                        "builderid": 26,
                        "description": null,
                        "masterids": [],
                        "name": "buildbot SQLALCHEMY:latest TESTS:trial TWISTED:trunk python:3.6",
                        "tags": [
                                "buildbot",
                                "SQLALCHEMY:latest",
                                "TESTS:trial",
                                "TWISTED:trunk",
                                "python:3.6"
                        ]
                }
        ],
        "meta": {
                "total": 26
        }
}
};